
#Function finds the average of all the items in an iterable
def average(iterable):
    sum = 0
    for i in iterable:
        sum+=i
    avg = sum/len(iterable)
    return (avg)

#Calculates the slope of 2 given points (x1, y1) (x2, y2)
def find_slope(x1, y1, x2, y2):
    return((y2-y1)/(x2-x1))


#Runs a linear regression of a list of points (iter_x[i], iter_y[i])
def lin_reg(iter_x, iter_y):
    slopes = []
    for i in range(len(iter_x)-1):
        slopes.append(find_slope(iter_x[i], iter_y[i], iter_x[i+1], iter_y[i+1]))
    return(average(slopes))


#Finds the y intercept of a given linear equation (y=mx+b).
#In this case, x and y are a list of points. The intercept is calculated by
#finding the distance between the actual y and the calculated y from m*x
#and averaging all of the distances together. This is the y intercept
def find_intercept(m, x, y):
    if len(x) == len(y):
        intercept = 0
        distances = []
        for i in range(len(x)):
            point = m*x[i]+intercept
            distances.append(y[i]-point)

        intercept_min = average(distances)
        return(intercept_min+(m*x[0]))


#The weighted regression makes a line based on past points, where each more
#recent point has a slightly higher weight on the overall average than the one
#previous.
def weighted_regression(iter_x, iter_y):
    slopes = []
    
    #Find the slope of all the points
    for i in range(len(iter_x)-1):
        slopes.append(find_slope(iter_x[i], iter_y[i], iter_x[i+1], iter_y[i+1]))

    #Final is the slope of the weighted regression
    final = 0
    iterations = 0

    #To weight the regression, we use slope*(time/total_time) for example if the
    #slopes were (2, 3, 4) and the times were (0, 1, 2, 3), the first point would
    # 2*(1/6), or 1/3
    for i in (range(len(iter_x)-1)):
        copy_x = [x for x in iter_x]
        copy_x.remove(copy_x[0])
        if abs(slopes[-(i+1)]) == slopes[-(i+1)]:

            
            final += slopes[i]*(copy_x[i]/recursion(copy_x))
        else:
            final += slopes[i]*(copy_x[i]/recursion(copy_x))
        iterations += 1
    return(final)


#Adds up all the values in an iterable
def recursion(iterable):
    tot = 0
    for i in iterable:
        tot += i
    return(tot)


#Determining the recent trend of the line
def recent_trend(iter_x, iter_y):
    x = []
    y = []

    #Reversing the lists
    for i in range(len(iter_x)):
        x.append(iter_x[-(i+1)])
        y.append(iter_y[-(i+1)])

    #Getting the first 5 points of a list (if there are 5 points)
    line = 0
    prev = 0
    if len(x) >= 5:
        recent = [x[i] for i in range(5)]
    else:
        recent = [x[i] for i in range(len(x))]

    #If the next point is within .15 of its expected point on the line,
    #include it and run another regression. Otherwise, the recent trend is
    #done.
    for i in range(len(x)-len(recent)):
        line = lin_reg(x[0:i+5], y[0:i+5])
        if prev != None:
            if line < prev * 1.15 and line > prev * 0.95:
                recent.append(x[i+4])
            else:
                break

    return([line, find_intercept(line, list(reversed(x[0:i+5])), list(reversed(y[0:i+5])))])
