def export_prediction(city='', data_file='Previous_Data.txt', default_weights=50, weight_file='weights.txt', output_file='crimedata.txt'):

    #Import the Get_Places file to get the latitudes and longitudes of addresses
    import Get_Places as gm

    #Import the googlemaps.exceptions library to get exceptions so that we can
    #determine a network error
    import googlemaps.exceptions as gm_excepts

    #Import the algorithms file for the prediction algorithms
    import Algorithms as tl

    #Import the datetime file to turn dates into number of days
    from datetime import datetime

    #Import tkinter and ttk for the progress bar
    import tkinter as tk
    from tkinter import ttk

    #Initializing the app for the progress bar
    root = tk.Tk()
    root.minsize(400, 150)
    root.title("Place Initialization")

    #Creating the UI for the progress bar
    place_text = tk.StringVar(root)
    place_label = tk.Label(root, textvariable=place_text)
    place_label.pack()
    net_text = tk.StringVar(root)
    net_label = tk.Label(root, textvariable=net_text)
    net_label.pack()
    incid_text = tk.StringVar(root)
    incid_label = tk.Label(root, textvariable=incid_text)
    incid_label.pack()

    #Opening the data, weight, and output files to read (data and weight files)
    #and write (output file) to
    data = open(data_file, 'r')
    out = open(output_file, 'w')
    weight_file = open(weight_file, 'r')

    #Creating a crime_data variable with all of the data from data. Files can
    #only be read once before closing, and we need to access the data from
    #the data file several times.
    crime_data = data.read().splitlines()

    #Set the maximum value of the progress bar to the amount of data
    progress = ttk.Progressbar(root, orient='horizontal', length=350, mode='determinate')
    progress['maximum'] = len(crime_data)
    progress.pack()

    #Creating dictionaries and lists to sort all of the data in the data file
    city_crime = {}
    rates = {}
    dates = []
    weights = {}
    
    #The number of days elapsed in each month of a leap year
    elapsedDaysLeap = {1: 0,
                        2: 31,
                        3: 31+29,
                        4: 31+29+31,
                        5: 31+29+31+30,
                        6: 31+29+31+30+31,
                        7: 31+29+31+30+31+30,
                        8: 31+29+31+30+31+30+31,
                        9: 31+29+31+30+31+30+31+31,
                        10: 31+29+31+30+31+30+31+31+30,
                        11: 31+29+31+30+31+30+31+31+30+31,
                        12: 31+29+31+30+31+30+31+31+30+31+30}

    #The number of days elapsed in each month of a normal year
    elapsedDays = {1: 0,
                    2: 31,
                    3: 31+28,
                    4: 31+28+31,
                    5: 31+28+31+30,
                    6: 31+28+31+30+31,
                    7: 31+28+31+30+31+30,
                    8: 31+28+31+30+31+30+31,
                    9: 31+28+31+30+31+30+31+31,
                    10: 31+28+31+30+31+30+31+31+30,
                    11: 31+28+31+30+31+30+31+31+30+31,
                    12: 31+28+31+30+31+30+31+31+30+31+30}

    #Iterating through every line in the weight file. The weight of each
    #incident is put in the weights dictionary, with incident as the key.
    for line in weight_file.read().splitlines():
        incident, weight = line.split('\t')
        weights[incident] = weight

    #A variable to count the iterations of the following for loop
    #lidi stands for Line In Data Iterable
    lidi = 1

    #Iterating through the lines in the data file
    for line in crime_data:

        #Stepping the progress bar forward one data point and resetting error
        #text
        progress.step()
        net_text.set('')
        incid_text.set('')
        root.update_idletasks()
        root.update()

        #Iterating 4 times. This allows up to 4 trials for internet failures
        for i in range(4):

            #A variable that states if the loop has so far completed. False if
            #the except statement runs
            complete = True

            #Allowing multiple trials in the case of a network error
            try:
                #Unpacking the line in the data file
                place, time, incident = line.split('\t')

                #Showing the address with the progress bar
                place_text.set('\n'+str(lidi)+': '+place+', '+incident)
                root.update()
                root.update_idletasks()
                
                #We add the city name to the address so that all 
                #places are in the same city
                if '/' in place:
                    ad1, ad2 = place.split('/')
                    ad1 += ' '+city
                    ad2 += ' '+city
                    place = ad1+' / '+ad2
                else:
                    place += ' '+city
                    
                #We turn the date into the number of days elapsed so far
                #in the year
                if datetime.strptime(time, "%m/%d/%Y %I:%M %p").year % 4 == 0:
                    time = datetime.strptime(time, "%m/%d/%Y %I:%M %p").day+elapsedDaysLeap[datetime.strptime(time, "%m/%d/%Y %I:%M %p").month]
                else:
                    time = datetime.strptime(time, "%m/%d/%Y %I:%M %p").day+elapsedDays[datetime.strptime(time, "%m/%d/%Y %I:%M %p").month]
                    
                #If this is a new place, we make a new dictionary for it
                #Otherwise, we add the time of an occurance to it
                if place not in city_crime:
                    city_crime[place] = {'times': [time], 'coord': gm.get_lat_long(place), 'weight': {}}
                else:
                    city_crime[place]['times'].append(time)
                    
                #Weighting the incident that happened and setting the
                #crime rate at that time equal to it
                if incident in weights:
                    if time in city_crime[place]['weight']:
                        city_crime[place]['weight'][time] += int(weights[incident])
                        
                    else:
                        city_crime[place]['weight'][time] = int(weights[incident])
                else:
                    if time in city_crime[place]['weight']:
                        city_crime[place]['weight'][time] += int(default_weights)
                        
                    else:
                        city_crime[place]['weight'][time] = int(default_weights)
                    incid_text.set(incident+ " is not a weighted incident. Defaulting to weight "+ str(default_weights))
                    root.update_idletasks()
                    root.update()

            #If a googlemaps timeout or transport error occurs, there was a
            #network error, and complete is set to false so that the loop does
            #not break and move onto the next data point, and lidi will not
            #incriment. This also sets errors
            except (gm_excepts.Timeout, gm_excepts.TransportError):
                complete = False
                if i == 3:
                    net_text.set("Network error, skipping address: "+place)
                    root.update()
                    root.update_idletasks()
                else:
                    net_text.set("Network error, retrying "+str(i+1)+' / 3')
                    root.update()
                    root.update_idletasks()

            #Breaks out of the loop to the next data point and incriments lidi
            if complete:
                lidi += 1
                break

    #Closes the progress bar
    root.destroy()
                
    #Getting the prediction for each data point
    for i in city_crime:
        time = list(city_crime[i]['weight'].keys())
        time.sort()
        rate = [city_crime[i]['weight'][x] for x in time]
        rates[(city_crime[i]['coord']['lat'], city_crime[i]['coord']['lng'])] = tl.average([tl.weighted_regression(time, rate), (float(rate[0]) *  float(tl.recent_trend(time, rate)[0]) + tl.recent_trend(time, rate)[1])])

    #Writing the predictions to the output data file
    for i in city_crime:
        for j in range(len(city_crime[i]['times'])):
            if city_crime[i]['coord']['lat'] != None:
                out.write(str(city_crime[i]['coord']['lat'])+','+str(city_crime[i]['coord']['lng'])+','+str(city_crime[i]['weight'][city_crime[i]['times'][j]])+'\n')

    #Closing the files
    data.close()
    out.close()
    weights.close()
