def officer_placement(qty_officers, data_file, output_file='policedata.txt', grid_area=1, max_officers=None):

    #Opening the data file that contains the prediction. We place officers based
    #on this prediction
    data = open(data_file, 'r')

    #Declaring dictionaries and lists to save the data form the data file into
    rates = {}
    rate_qty = []
    high_rates = []
    officer_places = []

    #The total rate of all of the crimes combined
    total_rate = 0

    #Checking to see if max_officers was given. If not, it is set to 10.
    if max_officers == None:
        max_officers = 10

    #Changing strings into useable integers and floats
    max_officers = int(max_officers)
    grid_area = float(grid_area)

    #Ensuring that the max number of officers is no greater than 10
    if max_officers > 10:
        max_officers = 10

    #The resolution at which the grid area will be.
    resolution = int(1/(grid_area/102470))

    #Iterating through the data file and unpacking the data. The latitude and
    #longitudes are multiplied by the resolution. Then, they get the amount of
    #weight added to them that they contain
    for line in data.read().splitlines():
        lat, long, weight = line.split(',')
        lat, long = int(float(lat)*resolution), int(float(long)*resolution)
        if (lat, long) in rates:
            rates[(lat, long)] += int(weight)
        else:
            rates[(lat, long)] = int(weight)

    #Calculating the total rate, with the sum of all of the other rates
    for i in rates:
        total_rate += rates[i]

    #The rate that each officer is expected to have in an ideal situation
    rate_rate = total_rate/qty_officers

    #The amount of rate in an area is given the number of officers it needs
    #based on the amount of rate each officer must have. This value cannot
    #exceed the maximum number of officers per grid. Once a place gets an
    #officer, its crime rate gets set to 0 so that places without officers have
    #priority.
    for i in rates:
        for j in range(min(int(rates[i]/rate_rate), max_officers)):
            officer_places.append((i[0]/resolution, i[1]/resolution))
            qty_officers-=1
        if int(rates[i]/rate_rate) >= 1:
            rates[i] = 0

    #The rates with all places with officers set to 0.
    for i in rates:
        rate_qty.append(rates[i])

    #Sorting the list from smallest to largest
    rate_qty.sort()

    #Taking the last values from the list based on how many officers remain
    high_rates = rate_qty[-qty_officers:]

    #Placing officers in all of the places with the highest rates
    for i in rates:
        if rates[i] in high_rates:
            officer_places.append((i[0]/(resolution), i[1]/(resolution)))
            high_rates.remove(rates[i])

    #Making a dictionary that has the number of officers paired with the place
    places_officers = {}
    for i in officer_places:
        if i not in places_officers:
            places_officers[i] = officer_places.count(i)

    #Writing all of the officer places to the file.
    out = open(output_file, 'w')
    for i in places_officers:
        out.write(str(i[0]+((grid_area/102470)/2))+','+str(i[1]+((grid_area/102470)/2))+','+str(places_officers[i])+'\n')

